//-----------------------------------------------------------------------------
//Test_Ufw_Tin_Tar.java
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
//Package Definition
//-----------------------------------------------------------------------------
package uicc.usim.test.usatframework.ufw_tin_tar;

import org._3gpp.ct.wg6.usim.jcapi.userclass.USimAPITestCardService;
import org.etsi.scp.wg3.uicc.jcapi.userclass.UiccTestModel;
import org.etsi.scp.wg3.uicc.jcapi.userinterface.APDUResponse;

//-----------------------------------------------------------------------------
//Imports
//-----------------------------------------------------------------------------

/**
 * Test Area : uicc.usim.test.usatframework.ufw_tin_tar
 *
 * @version 0.0.1 - 13 sept. 2005
 * @author 3GPP T3 SWG API
 */
public class Test_Ufw_Tin_Tar extends UiccTestModel {


    static final String             CAP_FILE_PATH          = "uicc/usim/test/usatframework/ufw_tin_tar";

    private final String            CLASS_AID_1            = "A0000000 871005FF FFFFFF89 50010001";
    private final String            APPLET_AID_1           = "A0000000 871005FF FFFFFF89 50010102";
    private final String            APPLET_AID_1_NO_TAR    = "A0000000 871005FF FFFFFF89 02";
    
    /** */
    private USimAPITestCardService test;
    /** contains the response of the processed apdu*/
    private APDUResponse response;

    private static String           ADF_1_AID           = "A0000000090005FFFFFFFF89E0000002";;
    /** */
    public Test_Ufw_Tin_Tar() {
        test = USimAPITestCardService.getTheUSimTestCardService();
    }
    /**
     * @todo terminal profile
     */
    public boolean run() {
            
            boolean result = false;
         
            // test script
            test.reset();
            test.terminalProfile("0301");
            // Install package
            test.loadPackage(CAP_FILE_PATH);
            
            // Test case 1 : Installation with no TAR within applet AID 
            //               and several TAR value in install parameter
            
            // 1.1 Install Applet1 with different TAR value
            test.installApplet(CAP_FILE_PATH, CLASS_AID_1, APPLET_AID_1_NO_TAR, 
                                "800E" + // TLV UICC Toolkit application specific parameters
                                "01" +   // V Priority Level
                                "00" +   // V Max. number of timers
                                "00" +   // V Maximum text length for a menu entry
                                "00" +   // V Maximum number of menu entries                              
                                "00" +   // V Maximum number of channels 
                                "00" +   // LV Minimum Security Level field
                                "06111111 222222" +   // LV TAR Value(s) 
                                "00" );  // V Maximum number of services
            
          
            // terminal profile
            test.reset();
            test.terminalProfileSession("03010000 0102");
            
            // 1.2 Single SMSPP is sent to applet1 without any security and TAR set to 11 11 11
            response = test.envelopeSmsPp("8B254008 81556677 887FF600 11291200"
                                        + "00041402 7000000F 0D080010 10111111"
                                        + "00000000 010005");
            result = response.checkSw("9000");

            // 1.3 Single SMSPP is sent to applet1 without any security and TAR set to 22 22 22
            response = test.envelopeSmsPp("8B254008 81556677 887FF600 11291200"
                                        + "00041402 7000000F 0D080010 10222222"
                                        + "00000000 010005");
            result = response.checkSw("9000");
            
            //get test result
            response = test.selectApplication(APPLET_AID_1_NO_TAR);
            result &= response.checkData("0D"+APPLET_AID_1_NO_TAR+ 
                                         "02CCCC");

            // 1.4 Delete the applet instance
            test.reset();
            test.terminalProfile("0301");
            test.deleteApplet(APPLET_AID_1_NO_TAR);
            
            // Test case 2 : Installation with TAR defined in AID

            // 2.1 Install applet1 TAR defined within AID
            test.installApplet(CAP_FILE_PATH, CLASS_AID_1, APPLET_AID_1, 
                               "8008" + // TLV UICC Toolkit application specific parameters
                               "01" +   // V Priority Level
                               "00" +   // V Max. number of timers
                               "00" +   // V Maximum text length for a menu entry
                               "00" +   // V Maximum number of menu entries                              
                               "00" +   // V Maximum number of channels 
                               "00" +   // LV Minimum Security Level field
                               "00" +   // LV TAR Value(s) 
                               "00" );  // V Maximum number of services

            // terminal profile
            test.reset();
            test.terminalProfileSession("03010000 0102");

            // 2.2 Single SMSPP is sent to applet1 without any security
            response = test.envelopeSmsPp("8B254008 81556677 887FF600 11291200"
                                        + "00041402 7000000F 0D080010 10500101"
                                        + "00000000 010005");
            result &= response.checkSw("9000");

            //get test result
            response = test.selectApplication(APPLET_AID_1);
            result &= response.checkData("10"+APPLET_AID_1+ 
                                         "01CC");

            // 2.3 Delete the applet instance
            test.reset();
            test.terminalProfile("0301");
            test.deleteApplet(APPLET_AID_1);

            // Test case 3 : Installation with TAR value within AID different
            //               from the one define in install parameters

            // 3.1 Install applet1 with TAR value set to 11 11 11
            test.installApplet(CAP_FILE_PATH, CLASS_AID_1, APPLET_AID_1, 
                               "800B" + // TLV UICC Toolkit application specific parameters
                               "01" +   // V Priority Level
                               "00" +   // V Max. number of timers
                               "00" +   // V Maximum text length for a menu entry
                               "00" +   // V Maximum number of menu entries                              
                               "00" +   // V Maximum number of channels 
                               "00" +   // LV Minimum Security Level field
                               "03111111" +   // LV TAR Value(s) 
                               "00" );  // V Maximum number of services

            // terminal profile
            test.reset();
            test.terminalProfileSession("03010000 0102");

            // 3.2 Single SMSPP is sent to applet1 using the TAR defined in AID
            response = test.envelopeSmsPp("8B254008 81556677 887FF600 11291200"
                                        + "00041402 7000000F 0D080010 10500101"
                                        + "00000000 010005");
            result &= response.checkSw("9000");
 
            // 3.3 Single SMSPP is sent to applet1 using the TAR defined in install parameter
            response = test.envelopeSmsPp("8B254008 81556677 887FF600 11291200"
                                        + "00041402 7000000F 0D080010 10111111"
                                        + "00000000 010005");
            result &= response.checkSw("9000");

            //get test result
            response = test.selectApplication(APPLET_AID_1);
            result &= response.checkData("10"+APPLET_AID_1+ 
                                         "01CC");

            // Test case 4 : Installation with TAR value already assigned            
            test.reset();
            test.terminalProfile("0301");
            // 4.1 Install applet1 with TAR value set to 11 11 11 and no TAR in AID
            response = test.installApplet(CAP_FILE_PATH, CLASS_AID_1, APPLET_AID_1_NO_TAR, 
                                          "800B" + // TLV UICC Toolkit application specific parameters
                                          "01" +   // V Priority Level
                                          "00" +   // V Max. number of timers
                                          "00" +   // V Maximum text length for a menu entry
                                          "00" +   // V Maximum number of menu entries                              
                                          "00" +   // V Maximum number of channels 
                                          "00" +   // LV Minimum Security Level field
                                          "03111111" +   // LV TAR Value(s) 
                                          "00" );  // V Maximum number of services
            result &= response.checkSw("6A80");
            
            // delete applet 
            test.reset();
            test.terminalProfile("0301");
            test.deleteApplet(APPLET_AID_1);

            // Test case 5 : Installation with incorrect TAR value length in install parameter
            
            // 5.1 Install applet with no TAR in AID and TAR value LV length set to 02
            response = test.installApplet(CAP_FILE_PATH, CLASS_AID_1, APPLET_AID_1_NO_TAR, 
                                          "800A" + // TLV UICC Toolkit application specific parameters
                                          "01" +   // V Priority Level
                                          "00" +   // V Max. number of timers
                                          "00" +   // V Maximum text length for a menu entry
                                          "00" +   // V Maximum number of menu entries                              
                                          "00" +   // V Maximum number of channels 
                                          "00" +   // LV Minimum Security Level field
                                          "021111" +   // LV TAR Value(s) 
                                          "00" );  // V Maximum number of services
            result &= response.checkSw("6A80");
            
            // 5.2 Install applet with no TAR in AID and TAR value LV length set to 05
            response = test.installApplet(CAP_FILE_PATH, CLASS_AID_1, APPLET_AID_1_NO_TAR, 
                                          "800D" + // TLV UICC Toolkit application specific parameters
                                          "01" +   // V Priority Level
                                          "00" +   // V Max. number of timers
                                          "00" +   // V Maximum text length for a menu entry
                                          "00" +   // V Maximum number of menu entries                              
                                          "00" +   // V Maximum number of channels 
                                          "00" +   // LV Minimum Security Level field
                                          "05111111 2222" +   // LV TAR Value(s) 
                                          "00" );  // V Maximum number of services
            result &= response.checkSw("6A80");
            
            // delete package
            test.reset();
            test.terminalProfile("0301");
            test.deletePackage(CAP_FILE_PATH);

            return result;
    }
}
